<?php
namespace Neuron\Person\Controller\Api;

use Neuron\Actor;
use Neuron\Composite;
use Neuron\Generic\Result;  
use Neuron\Application\Framework\Entity;
use Neuron\Person\Attribute as AttrModel;
use Neuron\Person\Attribute\Type as AttrTypeModel;
use Neuron\Person\Entity as mEntity;
use Neuron\Person\Entities as mEntities;

class Person extends \Neuron\Person\Controller {
    const EVENT_SUBJECT = 'Person';
    const SUCCESS_CODE = 0;
    const FAIL_CODE = 1;
    const FAIL_CODE_SESSION = 11;

    const CODE_FIELD_REQUIRED  = 400;
    const CODE_UNAUTHORIZED = 401;
    const CODE_SESSION_EXPIRED = 403;


    public function biodataAction(){
        $result = new \Neuron\Generic\Result();
        
        $request = $this->getRequest();

        if (!$request->isPost()) {
            $result->code = self::FAIL_CODE;
            $result->info = 'Method not allowed';
            return $this->getREST()->getResponse($result);
            
        }

        $data = $this->getREST()->getParameters();
        $guid = $this->getGuid();
        // print_r($session_id); die();
        try {
            if($guid == "" || empty($guid)){
                $result->code = self::CODE_FIELD_REQUIRED;
                $result->info = 'token is null';
                return $this->getREST()->getResponse($result);   
            }
            
            $entity = Entity::get($this, $guid);
            $user = $entity->user();
            if(!$user->id){
                $result->code = self::CODE_SESSION_EXPIRED;
                $result->info = 'Session Expired';
                return $this->getREST()->getResponse($result); 
            }

            $userPerson = $this->getUserPerson($user);
            $attrs = array();
            $filterAttr['person_id'] = $userPerson['person']['person_id'];
            $attrModel 	= new \Neuron\Person\Attributes(AttrModel\Storage::factory($this->getDb(),$this->getConfig()));
            $empAttr 	= $attrModel->load($userPerson['person']['person_id'], AttrModel\Storage::LISTBY_PERSONID);

            $attrModel 	= new \Neuron\Person\Attribute\Types(AttrTypeModel\Storage::factory($this->getDb(),$this->getConfig()));
            $dataAttr 	= $attrModel->load();
            if($dataAttr->code== 0){
                foreach ($dataAttr->data['list'] as $value) {
                    if($empAttr->code ==0 ){
                        foreach ($empAttr->data['list'] as $empVal) {
                            if($value['attr_code'] == $empVal['attr_code']){
                                $empVal['end_date'] = null;
                                $value = $empVal;
                            }
                        }
                    }
                    $attrs[]  = $value;
                }
            }	


            $storagePerson = \Neuron\Employee\Entity\Storage::factory($this->getDb(), $this->getConfig());
            $cEmployee = new \Neuron\Employee\Entity($storagePerson);
            $cEmployee->load($userPerson['person']['ref_id'], \Neuron\Employee\Entity\Storage::LOADBY_PERSON);
            $employee = $cEmployee->person()->pull();
            $profile = $cEmployee->detail()->pull();
            $type = $cEmployee->type()->pull();
            $job = $cEmployee->job();
            $ohp = $job->ohp();
            $dataJob = $ohp->pull(10);

            $profile['pic_official'] = $this->getPublicURL().$profile['pic_official'];
            $profile['pic_signature'] = $this->getPublicURL().$profile['pic_signature'];
            $profile['email'] = $user->email;
            $profile['pos_name'] = $dataJob['title'];
            $profile['org_name'] = $dataJob['org_name'];
            $profile['type_name'] = $type['name'];

            $profile = array_merge($employee, $profile, $cEmployee->pull());

            if(class_exists('Neuron\Contact\Entity')){
                $storage = \Neuron\Contact\Entity\Storage::factory($this->getDb(), $this->getConfig());
                $ccontact = new \Neuron\Contact\Entities($storage);

                $storageDetail = \Neuron\Contact\Detail\Storage::factory($this->getDb(), $this->getConfig());
                $cdetail = new \Neuron\Contact\Detail($storageDetail);

                $filter = array('searchField' => 'ref_id', 'searchValue' => $userPerson['person']['ref_id']);
                $datacontact = $ccontact->listContact(0, 999, $filter);
                $contact = array();
                if($datacontact['rows']){
                    foreach ($datacontact['rows'] as $val) {
                        $val['detail'] = array();
                        $datadeatail = $cdetail->load($val['id']);
                        if($datadeatail){
                            foreach ($datadeatail as $detail) {
                                array_push($val['detail'], $detail);
                            }
                        }
                        array_push($contact, $val);
                    }
                }
            }else{
                $contact = null;
            }

            $dataRes = array('profile'=>$profile,'contact'=>$contact, 'attributes'=>$attrs);
            $result->guid = $guid;
            $result->code = self::SUCCESS_CODE;
            $result->info = 'OK';
            $result->data = $dataRes;
        
        } catch (Exception $e) {
            $result->code = self::FAIL_CODE;
            $result->info = 'error';
            $result->data = array(
                'message' => $ex->getMessage(),
            );
        }
		
		$requestPost = array(
			'guid' => $guid,
			'code' => '',
			'info' => '',
			'data' => $data
		); 

		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 

		$logparam['subject'] = 'API PERSON BIODATA';
		$logparam['identity'] = $user->id ? $user->id : '';
		$logparam['user'] = $user->id ? $user->id : '' ;
		$logparam['description'] = 'Log proses api person biodata';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
		return $this->getREST()->getResponse($result);
        
    }

	public function globalSearchAction()
	{
		$result 	= new Result();

        $request = $this->getRequest();

        if (!$request->isPost()) {
            $result->code = self::FAIL_CODE;
            $result->info = 'Method not allowed';
            return $this->getREST()->getResponse($result);
            
        }

		$post       = $this->getREST()->getParameters();
        $guid       = $this->getGuid();
		
		try {
            if($guid == "" || empty($guid)){
                $result->code = self::CODE_FIELD_REQUIRED;
                $result->info = 'token is null';
                return $this->getREST()->getResponse($result);   
            }

            $entity = Entity::get($this, $guid);
            $user = $entity->user();
            if(!$user->id){
                $result->code = self::CODE_SESSION_EXPIRED;
                $result->info = 'Session Expired';
                return $this->getREST()->getResponse($result); 
            }

			$post['start']	= 0;
			$post['length']	= 3;
			$params = array(
				'page' 		=> ($post['start'] + $post['length']) / $post['length'],
				'records' 	=> $post['length'],
			);
			$keywords 		= $post['keywords'];

			$mEntities 		= new mEntities(mEntity\Storage::factory($this->getDb(), $this->getConfig()));
            $entities 		= $mEntities->load($keywords, mEntity\Storage::LISTBY_PAGE, $params);
			$rows  			= $entities->data['rows'];
			$array          = [];
            
			if ($rows) {
				foreach ($rows as $key) {
                    $row['module']  = 'Person';
					$row['id']		= $key['id'];
					$row['title']	= $key['first_name'].' '.$key['last_name'];

					if (class_exists('\Neuron\Employee\Entity')) {
						$emp	= new \Neuron\Employee\Entity(\Neuron\Employee\Entity\Storage::factory($this->getDb(), $this->getConfig()));
						$emp->load($key['id'], \Neuron\Employee\Entity\Storage::LOADBY_PERSON);
						$row['url']	= $emp->code ? $this->getPublicUrl().'/actor/form/profile/'.$emp->code : null;
					} else {
						$row['url']	= '';
					}
                    $row['summary'] = isset($key['description']) ? $row['description'] : $this->translate('this person have no description');

					$array[]	= $row;		
				}
			}

            $requestPost = array(
				'guid' => $guid,
				'code' => '',
				'info' => '',
				'data' => $data
			); 

            $result->guid = $guid;
            $result->code = self::SUCCESS_CODE;
            $result->data = $array;
            
            $responseResult = array(
                'guid' => $result->guid,
                'code' => $result->code,
                'info' => $result->info,
                'data' => $result->data
            ); 

            $logparam['subject'] = 'API PERSON LISTEDUCATION';
            $logparam['identity'] = $user->id ? $user->id : '';
            $logparam['user'] = $user->id ? $user->id : '';
            $logparam['description'] = 'Log proses api person list Education';
            $logparam['request'] = json_encode($requestPost);
            $logparam['response'] = json_encode($responseResult);
            
            $this->writeLogAction($logparam);
		} catch (\Exception $th) {
			$result->code = self::FAIL_CODE;
            $result->info = 'error';
            $result->data = array(
                'message' => $ex->getMessage(),
            );
		}

		return $this->getRest()->getResponse($result);
	}

    public function listEducationAction() {
		$storage = \Neuron\Person\Education\Storage::factory($this->getDb(), $this->getConfig());
		$cedu = new \Neuron\Person\Educations($storage);
        $result = new \Neuron\Generic\Result();
        
        $request = $this->getRequest();

        if (!$request->isPost()) {
            $result->code = self::FAIL_CODE;
            $result->info = 'Method not allowed';
            return $this->getREST()->getResponse($result);
            
        }

        $data = $this->getREST()->getParameters();
        $guid = $this->getGuid();
		
        try {
            if($guid == "" || empty($guid)){
                $result->code = self::CODE_FIELD_REQUIRED;
                $result->info = 'token is null';
                return $this->getREST()->getResponse($result);   
            }
            
            $entity = Entity::get($this, $guid);
            $user = $entity->user();
            if(!$user->id){
                $result->code = self::CODE_SESSION_EXPIRED;
                $result->info = 'Session Expired';
                return $this->getREST()->getResponse($result); 
            }

            $userPerson = $this->getUserPerson($user);
            $filter['person_id'] =  $userPerson['person']['ref_id'];
            $data = $this->getPostParams();
            $arr = $cedu->listdata($filter);
			
			$requestPost = array(
				'guid' => $guid,
				'code' => '',
				'info' => '',
				'data' => $data
			); 
			
            if(!empty($filter['draw'])){
                echo json_encode($arr);
				
				$logparam['subject'] = 'API PERSON LISTEDUCATION';
				$logparam['identity'] = $user->id ? $user->id : '';
				$logparam['user'] = $user->id ? $user->id : '';
				$logparam['description'] = 'Log proses api person list Education';
				$logparam['request'] = json_encode($requestPost);
				$logparam['response'] = json_encode($arr);
				
				$this->writeLogAction($logparam);
				
                return $this->getResponse();
            }else{
                $result->guid = $guid;
                $result->code = self::SUCCESS_CODE;
                $result->data = $arr['data'];
				
				$responseResult = array(
					'guid' => $result->guid,
					'code' => $result->code,
					'info' => $result->info,
					'data' => $result->data
				); 

				$logparam['subject'] = 'API PERSON LISTEDUCATION';
				$logparam['identity'] = $user->id ? $user->id : '';
				$logparam['user'] = $user->id ? $user->id : '';
				$logparam['description'] = 'Log proses api person list Education';
				$logparam['request'] = json_encode($requestPost);
				$logparam['response'] = json_encode($responseResult);
				
				$this->writeLogAction($logparam);
				
                return $this->getREST()->getResponse($result);
            }
        } catch (Exception $ex) {
            $result->code = self::FAIL_CODE;
            $result->info = 'error';
            $result->data = array(
                'message' => $ex->getMessage(),
            );
            return $this->getREST()->getResponse($result);
        }
    }
    
    public function listExperienceAction() {
		$storage = \Neuron\Person\Experience\Storage::factory($this->getDb(), $this->getConfig());
		$cexp = new \Neuron\Person\Experiences($storage);
        $result = new \Neuron\Generic\Result();
        
        $request = $this->getRequest();

        if (!$request->isPost()) {
            $result->code = self::FAIL_CODE;
            $result->info = 'Method not allowed';
            return $this->getREST()->getResponse($result);
            
        }

        $data = $this->getREST()->getParameters();
        $guid = $this->getGuid();
        try {
            if($guid == "" || empty($guid)){
                $result->code = self::CODE_FIELD_REQUIRED;
                $result->info = 'token is null';
                return $this->getREST()->getResponse($result);   
            }
            
            $entity = Entity::get($this, $guid);
            $user = $entity->user();
            if(!$user->id){
                $result->code = self::CODE_SESSION_EXPIRED;
                $result->info = 'Session Expired';
                return $this->getREST()->getResponse($result); 
            }

            $userPerson = $this->getUserPerson($user);
            $filter['person_id'] =  $userPerson['person']['ref_id'];
            $data = $this->getPostParams();
            $arr = $cexp->listdata($filter);
			
			$requestPost = array(
				'guid' => $guid,
				'code' => '',
				'info' => '',
				'data' => $data
			); 
			
            if(!empty($filter['draw'])){
                echo json_encode($arr);
				
				$logparam['subject'] = 'API PERSON listExperience';
				$logparam['identity'] = $user->id ? $user->id : '';
				$logparam['user'] = $user->id ? $user->id : '' ;
				$logparam['description'] = 'Log proses api person listExperience';
				$logparam['request'] = json_encode($requestPost);
				$logparam['response'] = json_encode($arr);

				$this->writeLogAction($logparam);
				
                return $this->getResponse();
            }else{
                $result->guid = $guid;
                $result->code = self::SUCCESS_CODE;
                $result->data = $arr['data'];
				
				$responseResult = array(
					'guid' => $result->guid,
					'code' => $result->code,
					'info' => $result->info,
					'data' => $result->data
				); 
				
				$logparam['subject'] = 'API PERSON listExperience';
				$logparam['identity'] = $user->id ? $user->id : '';
				$logparam['user'] = $user->id ? $user->id : '';
				$logparam['description'] = 'Log proses api person listExperience';
				$logparam['request'] = json_encode($requestPost);
				$logparam['response'] = json_encode($responseResult);

				$this->writeLogAction($logparam);
				
                return $this->getREST()->getResponse($result);
            }
        } catch (Exception $ex) {
            $result->code = self::FAIL_CODE;
            $result->info = 'error';
            $result->data = array(
                'message' => $ex->getMessage(),
            );
			
			$responseResult = array(
				'guid' => $result->guid,
				'code' => $result->code,
				'info' => $result->info,
				'data' => $result->data
			); 

			$logparam['subject'] = 'API PERSON listExperience';
			$logparam['identity'] = $user->id ? $user->id : '';
			$logparam['user'] = $user->id ? $user->id : '';
			$logparam['description'] = 'Log proses api person listExperience';
			$logparam['request'] = json_encode($requestPost);
			$logparam['response'] = json_encode($responseResult);
			
            return $this->getREST()->getResponse($result);
        }
    }

    public function listFamilyAction() {
		$storage = \Neuron\Person\Family\Storage::factory($this->getDb(), $this->getConfig());
		$cfam = new \Neuron\Person\Families($storage);
        $result = new \Neuron\Generic\Result();
        
        $request = $this->getRequest();

        if (!$request->isPost()) {
            $result->code = self::FAIL_CODE;
            $result->info = 'Method not allowed';
            return $this->getREST()->getResponse($result);
            
        }

        $data = $this->getREST()->getParameters();
        $guid = $this->getGuid();
        try {
            if($guid == "" || empty($guid)){
                $result->code = self::CODE_FIELD_REQUIRED;
                $result->info = 'token is null';
                return $this->getREST()->getResponse($result);   
            }
            
            $entity = Entity::get($this, $guid);
            $user = $entity->user();
            if(!$user->id){
                $result->code = self::CODE_SESSION_EXPIRED;
                $result->info = 'Session Expired';
                return $this->getREST()->getResponse($result); 
            }

            $userPerson = $this->getUserPerson($user);
            $filter['person_id'] =  $userPerson['person']['ref_id'];
            $data = $this->getPostParams();
            $arr = $cfam->listdata($filter);
			
			$requestPost = array(
				'guid' => $guid,
				'code' => '',
				'info' => '',
				'data' => $data
			); 
			
            if(!empty($filter['draw'])){
                echo json_encode($arr);
				
				$logparam['subject'] = 'API PERSON LISTFAMILY';
				$logparam['identity'] = $user->id ? $user->id : '';
				$logparam['user'] = $user->id ? $user->id : '';
				$logparam['description'] = 'Log proses api person listFamily';
				$logparam['request'] = json_encode($requestPost);
				$logparam['response'] = json_encode($arr);

				$this->writeLogAction($logparam);
				
                return $this->getResponse();
            }else{
                $result->guid = $guid;
                $result->code = self::SUCCESS_CODE;
                $result->data = $arr['data'];
				
				$responseResult = array(
					'guid' => $result->guid,
					'code' => $result->code,
					'info' => $result->info,
					'data' => $result->data
				); 
				
				$logparam['subject'] = 'API PERSON LISTFAMILY';
				$logparam['identity'] = $user->id ? $user->id : '';
				$logparam['user'] = $user->id ? $user->id : '';
				$logparam['description'] = 'Log proses api person listFamily';
				$logparam['request'] = json_encode($requestPost);
				$logparam['response'] = json_encode($responseResult);

				$this->writeLogAction($logparam);
				
                return $this->getREST()->getResponse($result);
            }
        } catch (Exception $ex) {
            $result->code = self::FAIL_CODE;
            $result->info = 'error';
            $result->data = array(
                'message' => $ex->getMessage(),
            );
			
			$responseResult = array(
				'guid' => $result->guid,
				'code' => $result->code,
				'info' => $result->info,
				'data' => $result->data
			); 
			
			$logparam['subject'] = 'API PERSON LISTFAMILY';
			$logparam['identity'] = $user->id ? $user->id : '';
			$logparam['user'] = $user->id ? $user->id : '';
			$logparam['description'] = 'Log proses api person listFamily';
			$logparam['request'] = json_encode($requestPost);
			$logparam['response'] = json_encode($responseResult);

			$this->writeLogAction($logparam);
			
            return $this->getREST()->getResponse($result);
        }
    }

    public function listMedicalAction() {
		$storage = \Neuron\Person\Medical\Storage::factory($this->getDb(), $this->getConfig());
		$cmed = new \Neuron\Person\Medicals($storage);
        $result = new \Neuron\Generic\Result();
        
        $request = $this->getRequest();

        if (!$request->isPost()) {
            $result->code = self::FAIL_CODE;
            $result->info = 'Method not allowed';
            return $this->getREST()->getResponse($result);
            
        }

        $data = $this->getREST()->getParameters();
        $guid = $this->getGuid();
        try {
            if($guid == "" || empty($guid)){
                $result->code = self::CODE_FIELD_REQUIRED;
                $result->info = 'token is null';
                return $this->getREST()->getResponse($result);   
            }
            
            $entity = Entity::get($this, $guid);
            $user = $entity->user();
            if(!$user->id){
                $result->code = self::CODE_SESSION_EXPIRED;
                $result->info = 'Session Expired';
                return $this->getREST()->getResponse($result); 
            }

            $userPerson = $this->getUserPerson($user);
            $filter['person_id'] =  $userPerson['person']['ref_id'];
            $data = $this->getPostParams();
            $arr = $cmed->listdata($filter);
			
			$requestPost = array(
				'guid' => $guid,
				'code' => '',
				'info' => '',
				'data' => $data
			); 
			
            if(!empty($filter['draw'])){
                echo json_encode($arr);
				
				$logparam['subject'] = 'API PERSON LISTMEDICAL';
				$logparam['identity'] = $user->id ? $user->id : '';
				$logparam['user'] = $user->id ? $user->id : '';
				$logparam['description'] = 'Log proses api person listMedical';
				$logparam['request'] = json_encode($requestPost);
				$logparam['response'] = json_encode($arr);

				$this->writeLogAction($logparam);
				
                return $this->getResponse();
            }else{
                $result->guid = $guid;
                $result->code = self::SUCCESS_CODE;
                $result->data = $arr['data'];
				
				$responseResult = array(
					'guid' => $result->guid,
					'code' => $result->code,
					'info' => $result->info,
					'data' => $result->data
				); 
				
				$logparam['subject'] = 'API PERSON LISTMEDICAL';
				$logparam['identity'] = $user->id ? $user->id : '';
				$logparam['user'] = $user->id ? $user->id : '';
				$logparam['description'] = 'Log proses api person listMedical';
				$logparam['request'] = json_encode($requestPost);
				$logparam['response'] = json_encode($responseResult);

				$this->writeLogAction($logparam);
				
                return $this->getREST()->getResponse($result);
            }
        } catch (Exception $ex) {
            $result->code = self::FAIL_CODE;
            $result->info = 'error';
            $result->data = array(
                'message' => $ex->getMessage(),
            );
			
			$responseResult = array(
				'guid' => $result->guid,
				'code' => $result->code,
				'info' => $result->info,
				'data' => $result->data
			); 
			
			$logparam['subject'] = 'API PERSON LISTMEDICAL';
			$logparam['identity'] = $user->id ? $user->id : '';
			$logparam['user'] = $user->id ? $user->id : '';
			$logparam['description'] = 'Log proses api person listMedical';
			$logparam['request'] = json_encode($requestPost);
			$logparam['response'] = json_encode($responseResult);

			$this->writeLogAction($logparam);
			
            return $this->getREST()->getResponse($result);
        }
    }

    public function saveProfileAction() {
        $result = new \Neuron\Generic\Result();
        
        $request = $this->getRequest();

        if (!$request->isPost()) {
            $result->code = self::FAIL_CODE;
            $result->info = 'Method not allowed';
            return $this->getREST()->getResponse($result);
            
        }

        $data = $this->getREST()->getParameters();
        $guid = $this->getGuid();
        $params = isset($data['params'])? $data['params']:null;
		
		$requestPost = array(
			'guid' => $guid,
			'code' => '',
			'info' => '',
			'data' => $data
		);
		
        try {
            if($guid == "" || empty($guid)){
                $result->code = self::CODE_FIELD_REQUIRED;
                $result->info = 'token is null';
                return $this->getREST()->getResponse($result);   
            }
            
            $entity = Entity::get($this, $guid);
            $user = $entity->user();
            if(!$user->id){
                $result->code = self::CODE_SESSION_EXPIRED;
                $result->info = 'Session Expired';
                return $this->getREST()->getResponse($result); 
            }
            $dataAttribute 	= json_decode($params,true);
            $userPerson = $this->getUserPerson($user);

            $mEntity 		= new mEntity(mEntity\Storage::factory($this->getDb(), $this->getConfig()));
            $mEntity->load($userPerson['person']['id']);

            foreach ($params as $tosave) {
                if(array_key_exists("attr_code", $tosave) && $tosave["attr_code"]){
                    $attrModel 	= new AttrModel(AttrModel\Storage::factory($this->getDb(),$this->getConfig()));
                    $tosave['name'] = $tosave['attr_code'];

                    $result     = $attrModel->saveEx(
                        array($tosave),
                        array(),
                        $mEntity,
                        $this->getSession()->owner()
                    );
                    if($result->code != 0) {
                        $dataRes = array('success'=> false, 'message'=>'Error on save profile attribute');
                        $result->guid = self::SUCCESS_CODE;
                        $result->code = self::FAIL_CODE;
                        $result->info = 'Error on save profile attribute';
                        $result->data = $dataRes;
						
						$responseResult = array(
							'guid' => $result->guid,
							'code' => $result->code,
							'info' => $result->info,
							'data' => $result->data
						); 
						
						$logparam['subject'] = 'API PERSON SAVEPROFILE';
						$logparam['identity'] = $user->id ? $user->id : '';
						$logparam['user'] = $user->id ? $user->id : '';
						$logparam['description'] = 'Log proses api person saveProfile';
						$logparam['request'] = json_encode($requestPost);
						$logparam['response'] = json_encode($responseResult);

						$this->writeLogAction($logparam);
						
                        return $this->getREST()->getResponse($result);
                    }
                }else{
                    $storage = \Neuron\Person\Entity\Storage::factory($this->getDb(), $this->getConfig());
                    $person = new \Neuron\Person\Entity($storage);
                    $person->load($userPerson['person']['ref_id']);
                    
                    if ($tosave['name'] == 'birth_date' || $tosave['name'] == 'join_date') {
                        $tosave['value'] = date('Y-m-d', strtotime($tosave['value']));
                    }
                    
                    $prop = $tosave['name'];
                    $person->$prop = $tosave['value'];

                    $update = false;
                    if ($person->id)
                        $update = true;

                    $save = $person->save($update);
                    if(!$save) {
                        $dataRes = array('success'=> false, 'message'=>'Error on save profile');
                        $result->guid = self::SUCCESS_CODE;
                        $result->code = self::FAIL_CODE;
                        $result->info = 'Error on save profile';
                        $result->data = $dataRes;
						
						$responseResult = array(
							'guid' => $result->guid,
							'code' => $result->code,
							'info' => $result->info,
							'data' => $result->data
						); 
						
						$logparam['subject'] = 'API PERSON SAVEPROFILE';
						$logparam['identity'] = $user->id ? $user->id : '';
						$logparam['user'] = $user->id ? $user->id : '';
						$logparam['description'] = 'Log proses api person saveProfile';
						$logparam['request'] = json_encode($requestPost);
						$logparam['response'] = json_encode($responseResult);

						$this->writeLogAction($logparam);
						
                        return $this->getREST()->getResponse($result);
                    }
                }
            }

            // if ($save) {
                $dataRes = array('success'=> true, 'message'=>'Data saved!');

                $result->guid = $guid;
                $result->code = self::SUCCESS_CODE;
                $result->info = 'Data saved!';
                $result->data = $dataRes;
				
				$responseResult = array(
					'guid' => $result->guid,
					'code' => $result->code,
					'info' => $result->info,
					'data' => $result->data
				); 
				
				$logparam['subject'] = 'API PERSON SAVEPROFILE';
				$logparam['identity'] = $user->id ? $user->id : '';
				$logparam['user'] = $user->id ? $user->id : '';
				$logparam['description'] = 'Log proses api person saveProfile';
				$logparam['request'] = json_encode($requestPost);
				$logparam['response'] = json_encode($responseResult);

				$this->writeLogAction($logparam);
				
                return $this->getREST()->getResponse($result);
            // } else {
            //     $dataRes = array('success'=> false, 'message'=>'Error on save profile');
                
            //     $result->guid = $guid;
            //     $result->code = self::FAIL_CODE;
            //     $result->info = 'Error on save profile';
            //     $result->data = $dataRes;
				
			// 	$responseResult = array(
			// 		'guid' => $result->guid,
			// 		'code' => $result->code,
			// 		'info' => $result->info,
			// 		'data' => $result->data
			// 	); 
				
			// 	$logparam['subject'] = 'API PERSON SAVEPROFILE';
			// 	$logparam['identity'] = $user->id ? $user->id : '';
			// 	$logparam['user'] = $user->id ? $user->id : '';
			// 	$logparam['description'] = 'Log proses api person saveProfile';
			// 	$logparam['request'] = json_encode($requestPost);
			// 	$logparam['response'] = json_encode($responseResult);

			// 	$this->writeLogAction($logparam);
				
            //     return $this->getREST()->getResponse($result);
            // }
        } catch (Exception $e) {
            $result->code = self::FAIL_CODE;
            $result->info = 'error';
            $result->data = array(
                'message' => $ex->getMessage(),
            );
			
			$responseResult = array(
				'guid' => $result->guid,
				'code' => $result->code,
				'info' => $result->info,
				'data' => $result->data
			); 
			
			$logparam['subject'] = 'API PERSON SAVEPROFILE';
			$logparam['identity'] = $user->id ? $user->id : '';
			$logparam['user'] = $user->id ? $user->id : '';
			$logparam['description'] = 'Log proses api person saveProfile';
			$logparam['request'] = json_encode($requestPost);
			$logparam['response'] = json_encode($responseResult);

			$this->writeLogAction($logparam);
			
            return $this->getREST()->getResponse($result);
        }
    }
}
