<?php
namespace Neuron\Person;

use Neuron\Generic\Entity\Map;
use Neuron\Generic\Result;

class Medical extends \Neuron\Generic\Entity\Mapper {
		
	protected $_storage;

	public function __construct(\Neuron\Person\Medical\Storage\Skeleton $storage, $data = array()) {

		$this->_storage = $storage;

		parent::__construct(
			$data, 
			array(
					new Map('medical_id'),
					new Map('person_id'),
					new Map('medical_type_id'),
					new Map('medical_type_name', null, true),
					new Map('medical_description'),
					new Map('treatment_dat'),
					new Map('heredity_source')
			), 
			parent::CASE_INSENSITIVE
		);
	}

	public function load($id) {
		if ($data = $this->_storage->load($id)) {
			$this->push($data);
			return true;
		}
		return false;
	}

	public function save($update = false){
		if ($id = $this->_storage->save($this, $update)) {
			$this->medical_id = $id;
			return true;
		}
		return false;
	}

	public function delete($id) {
		/* init */
		$result = new Result();
		try {
			/* loaded? */
		
			if ($this->_storage->remove($id)) {

				$result->info = 'medical_trm_success';
			} else {

				//gagal
				$result->code = 51;
				$result->info = 'medical_trm_failed';

			}
				
			return $result;
		} catch (\Exception $ex) {
			error_log('Error at ' . $ex->getFile() . ' line ' . $ex->getLine() . ': ' . $ex->getMessage());
			$result->code = 500;
			$result->info = $ex->getMessage();
			return $result;
		}
    }

	public function create($data = array())
    {
		$result = new Result();
		$update = false;
		if($data['medical_id']){
			$update = true;
		}

		//create data relation
		$param = $this->pull();
		foreach($data as $k => $v){
			if(array_key_exists($k, $param)){
				$param[$k] = $v;
			}
		}

		$this->push($param);
		if($this->save($update)){
			$result->data = $this->medical_id;
		}
		return $result;
    }
		
}