<?php

namespace Neuron\Person\Skill\Type\Storage;

class Mysql extends \Neuron\Db\Storage implements Skeleton {
    protected $_nafManager = null;
	
	public function save(\Neuron\Person\Skill\Type $perSkill, $update = false) {
        if ($update) {
            $update = $this->update()
                ->table($this->_tables['person_skill_types'])
                ->set($this->__($perSkill->pull()))
                ->where($this->__(array('skill_type_id' => $perSkill->skill_type_id)));

            
            if ($this->execute($update)) {
                return $perSkill->skill_type_id;
            }
          
        } else {
            $perSkill->skill_type_id = null;
            $insert = $this->insert()
                        ->into($this->_tables['person_skill_types'])
                        ->values($this->__($perSkill->pull()));
            $save = $this->execute($insert);
            if ($save) {
                $perSkill->skill_type_id = $save;
                return $perSkill->skill_type_id;
            }
        }

        return false;
    }

    public function loadList($ids, $mode = \Neuron\Person\Skill\Storage::LIST_ALL, $params = null) {
        /* base select */
        $select = $this->select()
                ->from(array('a' => $this->_tables['person_skill_types']));

        /* loadby page */
        if ($mode == \Neuron\Person\Skill\Storage::LISTBY_PAGE) {
            /* order */
            if(array_key_exists('order', $params) && array_key_exists('columns', $params)){
                foreach($params['order'] as $order){
                    $columnName = $params['columns'][$order['column']]['data'];
                    $colIdentity = $this->_($columnName, 'a.');
					
                    $select->order($colIdentity . ' ' . $order['dir']);
                }
            }
            
            /* get pager */
            $pager = \Neuron\Db\Storage\Pager::sanitize($params);
            $select->limit($pager->getLimit())->offset($pager->getOffset())->cache(0);

            /* has keyword? */
            if (!empty($ids)) {
                $select->where->nest()
                    ->like($this->_('skill_code', 'a.'), '%' . trim($ids) . '%')
                ->unnest();

                $select->where->nest()
                    ->like($this->_('skill_name', 'a.'), '%' . trim($ids) . '%')
                ->unnest();
            }

        } else {
            $pager = new \Neuron\Db\Storage\Pager(1, 999999);
        }

        // echo str_replace('"','',$select->getSqlString()); die();
        try {
            if($rows = $this->fetchAll($select)){
                $result = new \stdClass();
                $result->list = $rows;
                $result->pager = $pager;
                $result->countTotal = $rows->total;
                return $result;
            }
            return false;
        } catch (\Exception $ex) {
            error_log('Error at ' . $ex->getFile() . ' line ' . $ex->getLine() . ': ' . $ex->getMessage());
            return false;
        }
    }

    public function remove($perSkillId) {
        $delete = $this->delete()
                        ->from($this->_tables['person_skill_types'])
                        ->where(array('skill_type_id' => $perSkillId));
                    
        return $this->execute($delete);
    }

    public function load($perSkillId) {
        $select = $this->select()
                        ->from($this->_tables['person_skill_types'])
                        ->where(array('skill_code' => $perSkillId));
        
        return $this->fetchRow($select);
    }

}